// Fetch the YAML file from the URL
const fetchYamlFile = async (url) => {
  try {
    const response = await fetch(url);
    if (!response.ok) {
      throw new Error(`HTTP error! status: ${response.status}`);
    }
    const yamlContent = await response.text();
    return jsyaml.load(yamlContent);
  } catch (error) {
    console.error('Error fetching YAML file:', error);
  }
};

// Filter news articles based on their dates and sort them
const filterAndSortNewsArticlesByDate = (newsArticles, today) => {
  return newsArticles
    .filter((article) => {
      const articleDate = new Date(article.date);
      return articleDate >= today;
    })
    .sort((a, b) => {
      const dateA = new Date(a.date), dateB = new Date(b.date);
      return dateA - dateB; // Sort by date ascending: closer dates first
    });
};

// Main function to fetch, filter, sort, and generate HTML content
const displayNewsArticles = async (url) => {
  const today = new Date();
  today.setHours(0, 0, 0, 0); // Ensure comparison starts from the beginning of today

  const newsArticles = await fetchYamlFile(url);
  const filteredSortedArticles = filterAndSortNewsArticlesByDate(newsArticles, today);
  const htmlContent = generateHtmlContent(filteredSortedArticles);

  document.getElementById('meldungen-container').innerHTML = htmlContent;
};

// Generate HTML content from the filtered and sorted news articles
const generateHtmlContent = (newsArticles) => {
  let htmlContent = '<ul style="list-style-type:none;">';
  newsArticles.forEach((article) => {
    const articleDate = new Date(article.date);
    // Format the date in a German-friendly format
    const germanFormattedDate = articleDate.toLocaleDateString('de-DE', {
      weekday: 'long',
      year: 'numeric', 
      month: 'long', 
      day: 'numeric', 
    });

    htmlContent += `<li>
                      <h2>${article.title}</h2>
                      <p><strong>Datum:</strong> ${germanFormattedDate}</p>
                      <p>${article.description}</p>
                    </li>`;
  });
  htmlContent += '</ul>';
  return htmlContent;
};

// Call the function with the URL of your .yml file
displayNewsArticles('/data/meldungen.yml');
