document.addEventListener('DOMContentLoaded', function () {
    const stNav = document.createElement("div");
    stNav.setAttribute('id', 'stickyNav');
    const mdMain = document.querySelector(".md-main");
    mdMain.insertBefore(stNav, mdMain.firstChild);
    const articles = document.querySelectorAll('hr + p');
    articles.forEach(p => {
        // Parse the date from the paragraph text
        const dateMatch = p.textContent.match(/date: "(\d{4}-\d{2}-\d{2})"/);
        if (!dateMatch) return;

        const articleDate = new Date(dateMatch[1]);
        const today = new Date();
        today.setHours(0, 0, 0, 0);

        if (articleDate > today) {
            // Hide future articles entirely, including the two <hr> and the paragraph
            p.previousElementSibling.style.display = 'none'; // Hide the first <hr>
            p.style.display = 'none'; // Hide the date paragraph
            let nextElement = p.nextElementSibling;
            if (nextElement && nextElement.tagName === 'HR') {
                nextElement.style.display = 'none'; // Hide the second <hr>
                nextElement = nextElement.nextElementSibling;
                while (nextElement && !nextElement.matches('hr')) {
                    nextElement.style.display = 'none'; // Hide each element until the next <hr>
                    nextElement = nextElement.nextElementSibling;
                }
            }
        } else {
            // Change the article's heading from h1 to h2
            const heading = p.nextElementSibling.nextElementSibling; // Assuming the heading follows the second <hr>
            if (heading && heading.tagName === 'H1') {
                const h2 = document.createElement('h2');
                h2.innerHTML = heading.innerHTML;
                h2.id = heading.id;
                heading.parentNode.replaceChild(h2, heading);

                // Display the release date immediately after the new h2 heading
                const dateString = articleDate.toLocaleDateString('de-DE', { year: 'numeric', month: 'long', day: 'numeric' });
                const dateParagraph = document.createElement('p');
                dateParagraph.textContent = `Veröffentlicht am: ${dateString}`;
                dateParagraph.style.fontStyle = 'italic';
                h2.parentNode.insertBefore(dateParagraph, h2.nextSibling);
            }
            // Remove the date paragraph as it's no longer needed
            p.style.display = 'none';
            // Ensure only one <hr> is visible before the article
            p.previousElementSibling.style.display = 'none'; // Hide the first <hr>
        }
    });
});


document.addEventListener('DOMContentLoaded', () => {
    const navContainer = document.getElementById('stickyNav');

    // Function to adjust the top style of the navigation bar
    const adjustNavTop = () => {
        const header = document.querySelector('.md-header.md-header--lifted');
        const banner = document.querySelector('.md-banner');
        let scrolled = 0;
        scrolled = document.body.scrollTop;
        const scrolled2 = document.documentElement.scrollTop;
        if (header && banner) {
            const headerHeight = header.offsetHeight + banner.offsetHeight;
            navContainer.style.top = `${headerHeight}px`;
        }
        if (header && banner && document.body.scrollTop > 0 || document.documentElement.scrollTop > 0) {
            const headerHeight = header.offsetHeight;
            navContainer.style.top = `${headerHeight}px`;
        }
    };

    // Call adjustNavTop initially and on window resize
    adjustNavTop();
    window.addEventListener('resize', adjustNavTop);
    window.addEventListener('scroll', adjustNavTop);

    const toggleButton = document.createElement('button');
    toggleButton.textContent = '❯'; // Right arrow as default
    toggleButton.classList.add('nav-toggle');
    navContainer.appendChild(toggleButton);

    const yearHeadings = document.querySelectorAll('h1[id^="news-aus"]');
    yearHeadings.forEach(heading => {
        const yearText = heading.textContent.replace('News aus ', '');
        const yearId = heading.id;
        const navLink = document.createElement('a');
        navLink.href = `#${yearId}`;
        navLink.textContent = yearText;
        navLink.addEventListener('click', (e) => {
            e.preventDefault();
            const target = document.querySelector(`#${yearId}`);
            target.scrollIntoView({ behavior: 'instant', block: "start" });
            window.scrollBy(0, -125); // Adjust this value as needed to scroll higher
        });
        navContainer.insertBefore(navLink, toggleButton); // Insert links before the toggle button
    });

    let isNavVisible = true;
    let linkWidth = navContainer.offsetWidth;
    toggleButton.addEventListener('click', () => {
        isNavVisible = !isNavVisible;
        document.querySelectorAll('div#stickyNav > a').forEach(link => {
            link.style.opacity = isNavVisible ? "1" : "0";
            link.style.transform = isNavVisible ? 'translateX(0)' : 'translateX(' + linkWidth + 'px)';
        });
        toggleButton.style.transform = isNavVisible ? 'translateX(0)' : 'translateX(' + linkWidth / 2 + 'px)';
        toggleButton.style.borderTop = isNavVisible ? '1px solid var(--tabs-font-color)' : '0px';
        toggleButton.style.borderRadius = isNavVisible ? '0 0 var(--border-radius) var(--border-radius)' : 'var(--border-radius)';
        toggleButton.textContent = isNavVisible ? '❯' : '❮'; // Change arrow direction
    });
});


